@@ -58,7 +58,8 @@ public:
 	bool run(const QString&);
 	
 	static bool verify(const QString&);
-
+	static void setExtraArgs(const QString&);
+	
 protected:
 	virtual ParseResult parseStdout(QString&, ParserDelim);
 
@@ -68,6 +69,9 @@ private:
 
 	/** The current state of the parser state machine. */
 	ParserState m_state;
+	
+	/** Additional ommand-line arguments (per-project). */
+	static QStringList s_slExtraArgs;
 };
 
 #endif
