@@ -58,11 +58,31 @@ public:
 	bool m_bFinished;
 };
 
+/**
+ * A set of unique strings.
+ * Qt3 does not have a set class, so this is a simple implementation based on
+ * a QDict of dummy int pointers.
+ * @author	Elad Lahav
+ */
+class StringSet : public QDict<int>
+{
+public:
+	StringSet() : QDict<int>() {}
+	
+	void insert(const QString& sItem) {
+		static int nDummy = 0;
+		QDict<int>::insert(sItem, &nDummy);
+	}
+	
+	bool exists(const QString& sItem) {
+		return find(sItem) != NULL;
+	}
+};
+
 /**
  * Scans a directory for files matching a given pattern, using a separate thread.
  * @author Elad Lahav
  */
-
 class DirScanner : public QThread
 {
 public: 
@@ -96,6 +116,12 @@ private:
 	/** Currently scanned directory. */
 	QDir m_dir;
 	
+	/**
+	 * A set of already-scanned directories (prevents infinite loops in case
+	 * of cyclic symbolic links in the scanned file system).
+	 */
+	StringSet m_setScanned;
+	
 	/** Pointer to a list of files indexed by the file path (used to identify
 		files that should not appear in the scan results.) */
 	QDict<QListViewItem>* m_pDicFiles;
