@@ -41,7 +41,8 @@
  */
 FileView::FileView(QWidget* pParent, const char* szName, WFlags fl) :
 	FileViewLayout(pParent, szName, fl),
-	m_pCurBranch(0)
+	m_pCurBranch(0),
+	m_sRoot("")
 {
 	QWidget* pPage;
 	
@@ -62,13 +63,6 @@ FileView::FileView(QWidget* pParent, const char* szName, WFlags fl) :
 		this, SLOT(slotTreeItemSelected(QListViewItem*)));
 	connect(m_pFileTree, SIGNAL(returnPressed(QListViewItem*)), this, 
 		SLOT(slotTreeItemSelected(QListViewItem*)));
-	
-	// Prompt the user for a new root for the file tree when the "Set Root..."
-	// button is clicked
-	connect(m_pRootButton, SIGNAL(clicked()), this, SLOT(slotChangeRoot()));
-	
-	// Emit the findFile() signal when the "Find File..." button is clicked
-	connect(m_pFindButton, SIGNAL(clicked()), this, SIGNAL(findFile()));
 }
 
 /**
@@ -84,11 +78,20 @@ FileView::~FileView()
  */
 void FileView::setRoot(const QString& sRoot)
 {
+	// Nothing to do if the given root is the same as the old one
+	if (sRoot == m_sRoot)
+		return;
+	
+	m_sRoot = sRoot;
+	
 	// Remove the current branch
 	if (m_pCurBranch)
 		m_pFileTree->removeBranch(m_pCurBranch);
 	
-	// Do nothing for an empty root directory
+	// Update the file list
+	m_pFileList->setRoot(sRoot);
+	
+	// Nothing more to do for an empty root directory
 	if (sRoot.isEmpty())
 		return;
 	
@@ -97,8 +100,6 @@ void FileView::setRoot(const QString& sRoot)
 	m_pCurBranch = m_pFileTree->addBranch(KURL(sRoot), fi.fileName());
 	m_pCurBranch->setChildRecurse(false);
 	m_pFileTree->setOpen(m_pCurBranch->root(), true);
-	
-	m_pFileList->setRoot(sRoot);
 }
 
 /**
@@ -110,23 +111,6 @@ void FileView::clear()
 	setRoot("");
 } 
 
-/**
- * Prompts the user for a new root for the file tree.
- * This slot is connected to the clicked() signal of the "Set Root" button.
- */
-void FileView::slotChangeRoot()
-{
-	QString sRoot;
-	
-	// Get a new root directory from the user
-	sRoot = KFileDialog::getExistingDirectory();
-	if (!sRoot.isEmpty()) {
-		// Set the new directory as the root of the file tree
-		setRoot(sRoot);
-		emit rootChanged(sRoot);
-	}
-}
-
 /**
  * Emits the fileRequested() signal when a file name is selected in the file 
  * tree. An item is selected by either double-clicking it or by hittin 
