@@ -127,6 +127,32 @@ void GraphNode::removeInEdges()
 }
 
 /**
+ * Returns the first found node connected to this one.
+ * This function is used with multi-call nodes for retrieving the parent node.
+ * @param	pNode
+ * @param	bCalled
+ */
+void GraphNode::getFirstNeighbour(GraphNode*& pNode, bool& bCalled)
+{
+	QDictIterator<GraphEdge> itrIn(m_dictInEdges);
+	QDictIterator<GraphEdge> itrOut(m_dictOutEdges);
+	
+	if (itrIn.current()) {
+		pNode = itrIn.current()->getHead();
+		bCalled = false;
+	}
+	else if (itrOut.current()) {
+		pNode = itrOut.current()->getTail();
+		bCalled = true;
+	}
+	else {
+		pNode = NULL;
+	}
+}
+
+/**
+ * Modifies the bounding rectangle of the node.
+ * @param	rect	The new coordinates to set
  */
 void GraphNode::setRect(const QRect& rect)
 {
@@ -148,6 +174,7 @@ void GraphNode::setRect(const QRect& rect)
 void GraphNode::drawShape(QPainter& painter)
 {
 	const QPen& pen = painter.pen();
+	const QFont& font = painter.font();
 	
 	// Draw the rectangle
 	painter.setPen(QPen(Qt::black));
@@ -155,5 +182,11 @@ void GraphNode::drawShape(QPainter& painter)
 	
 	// Draw the text
 	painter.setPen(pen);
-	painter.drawText(m_rect, Qt::AlignCenter, m_sFunc);
+	painter.setFont(m_font);
+	if (m_bMultiCall)
+		painter.drawText(m_rect, Qt::AlignCenter, "...");
+	else
+		painter.drawText(m_rect, Qt::AlignCenter, m_sFunc);
+	
+	painter.setFont(font);
 }
