@@ -912,7 +912,7 @@ void GraphWidget::slotShowCalled()
 	// Run a query for called functions
 	m_sQueriedFunc = pNode->getFunc();
 	m_bCalled = true;
-	m_pCscope->query(CscopeFrontend::Called, m_sQueriedFunc,
+	m_pCscope->query(CscopeFrontend::Called, m_sQueriedFunc, true,
 		Config().getGraphMaxNodeDegree());
 }
 
@@ -998,7 +998,7 @@ void GraphWidget::slotShowCalling()
 	// Run a query for called functions
 	m_sQueriedFunc = pNode->getFunc();
 	m_bCalled = false;
-	m_pCscope->query(CscopeFrontend::Calling, m_sQueriedFunc, 
+	m_pCscope->query(CscopeFrontend::Calling, m_sQueriedFunc, true,
 		Config().getGraphMaxNodeDegree());
 }
 
