@@ -403,6 +403,9 @@ void KScope::slotProjectProps()
 	SymbolCompletion::initAutoCompletion(opt.bACEnabled, opt.nACMinChars,
 		opt.nACDelay, opt.nACMaxEntries);
 	
+	// Set per-project command-line arguments for Ctags
+	CtagsFrontend::setExtraArgs(opt.sCtagsCmd);
+	
 	// Set the source root
 	m_pFileView->setRoot(pProj->getSourceRoot());
 }
@@ -517,10 +520,11 @@ void KScope::slotQueryQuickDef()
 	QString sSymbol;
 	QueryViewDlg* pDlg;
 	uint nType;
+	bool bCase;
 	
 	// Get the requested symbol and query type
 	nType = SymbolDlg::Definition;
-	if (!getSymbol(nType, sSymbol, false))
+	if (!getSymbol(nType, sSymbol, bCase, false))
 		return;
 		
 	// Create a modeless query view dialogue
@@ -646,9 +650,10 @@ void KScope::slotQuery(uint nType, bool bPrompt)
 {
 	QString sSymbol;
 	CallTreeDlg* pCallTreeDlg;
+	bool bCase;
 	
 	// Get the requested symbol and query type
-	if (!getSymbol(nType, sSymbol, bPrompt))
+	if (!getSymbol(nType, sSymbol, bCase, bPrompt))
 		return;
 		
 	if (nType == SymbolDlg::CallTree) {
@@ -660,7 +665,7 @@ void KScope::slotQuery(uint nType, bool bPrompt)
 	else {
 		// Run the requested query
 		nType = SymbolDlg::getQueryType(nType);
-		m_pQueryWidget->initQuery(nType, sSymbol);
+		m_pQueryWidget->initQuery(nType, sSymbol, bCase);
 		
 		// Ensure Query Window is visible
 		toggleQueryWindow(true);	
@@ -706,6 +711,9 @@ void KScope::openProject(const QString& sDir)
 	SymbolCompletion::initAutoCompletion(opt.bACEnabled, opt.nACMinChars,
 		opt.nACDelay, opt.nACMaxEntries);
 	
+	// Set per-project command-line arguments for Ctags
+	CtagsFrontend::setExtraArgs(opt.sCtagsCmd);
+	
 	// Create an initial query page
 	m_pQueryWidget->addQueryPage();
 	
@@ -1228,7 +1236,8 @@ void KScope::slotShowBookmarks()
  *					determined automatically
  * @return	true if the user hs enetered a symbol, false otherwise
  */
-bool KScope::getSymbol(uint& nType, QString& sSymbol, bool bPrompt)
+bool KScope::getSymbol(uint& nType, QString& sSymbol, bool& bCase,
+	bool bPrompt)
 {
 	EditorPage* pPage;
 	QString sSuggested;
@@ -1244,7 +1253,7 @@ bool KScope::getSymbol(uint& nType, QString& sSymbol, bool bPrompt)
 	}
 	
 	// Show the symbol dialogue
-	sSymbol = SymbolDlg::promptSymbol(this, nType, sSuggested);
+	sSymbol = SymbolDlg::promptSymbol(this, nType, sSuggested, bCase);
 
 	// Cannot accept empty strings
 	if (sSymbol.isEmpty())
