@@ -29,6 +29,7 @@
 #include <qpushbutton.h>
 #include <qspinbox.h>
 #include <qlabel.h>
+#include <qtextedit.h>
 #include <kurlrequester.h>
 #include <klineedit.h>
 #include <kmessagebox.h>
@@ -133,6 +134,8 @@ void NewProjectDlg::setProperties(const QString& sName, const QString& sPath,
 	// Add type strings to the types list box
 	for (itr = opt.slFileTypes.begin(); itr != opt.slFileTypes.end(); ++itr)
 		m_pTypesList->insertItem(*itr);
+	
+	m_pCtagsCmdEdit->setText(opt.sCtagsCmd);
 }
 
 /**
@@ -184,6 +187,8 @@ void NewProjectDlg::getOptions(ProjectBase::Options& opt)
 	opt.nACMinChars = m_pAutoCompDlg->m_nMinChars;
 	opt.nACDelay = m_pAutoCompDlg->m_nDelay;
 	opt.nACMaxEntries = m_pAutoCompDlg->m_nMaxEntries;
+	
+	opt.sCtagsCmd = m_pCtagsCmdEdit->text();
 }
 
 /**
