@@ -170,7 +170,8 @@ void Project::getOptions(Options& opt) const
 	opt.bSlowPathDef = m_pConf->readBoolEntry("SlowPathDef", DEF_SLOW_PATH);
 	opt.nAutoRebuildTime = m_pConf->readNumEntry("AutoRebuildTime");
 	opt.nTabWidth = m_pConf->readUnsignedNumEntry("TabWidth");
-		
+	opt.sCtagsCmd = m_pConf->readEntry("CtagsCommand", DEF_CTAGS_COMMAND);
+			
 	// Get auto-completion options
 	m_pConf->setGroup("AutoCompletion");
 	opt.bACEnabled = m_pConf->readBoolEntry("Enabled");
@@ -430,6 +431,7 @@ void Project::writeOptions(KConfig* pConf, const Options& opt)
 	pConf->writeEntry("SlowPathDef", opt.bSlowPathDef);		
 	pConf->writeEntry("AutoRebuildTime", opt.nAutoRebuildTime);
 	pConf->writeEntry("TabWidth", opt.nTabWidth);
+	pConf->writeEntry("CtagsCommand", opt.sCtagsCmd);
 	
 	// Set auto-completion options
 	pConf->setGroup("AutoCompletion");
