@@ -51,7 +51,7 @@ public:
 	~QueryWidget();
 
 	void addQueryPage();
-	void initQuery(uint, const QString&);
+	void initQuery(uint, const QString&, bool);
 	void applyPrefs();
 	void loadPages(const QString&, const QStringList&);
 	void savePages(const QString&, QStringList&);
