@@ -29,6 +29,7 @@
 #define SEARCHRESULTSDLG_H
 
 #include <qregexp.h>
+#include <qcheckbox.h>
 #include "searchresultslayout.h"
 
 /**
@@ -48,6 +49,11 @@ public:
 	int getColumn();
 	void getPattern(QRegExp&);
 		
+	/**
+	 * @return	true if the search pattern should be negated, false otherwise
+	 */
+	bool isNegated() { return m_pNegateCheck->isChecked(); }
+	
 protected slots:
 	virtual void accept();
 	
@@ -60,6 +66,9 @@ private:
 	
 	/** Remembers the last value of the Case Sensitive check-box. */
 	static bool s_bCaseSensitive;
+	
+	/** Remembers the last value of the Negate Search check-box. */
+	static bool s_bNegate;
 };
 
 #endif
