@@ -36,6 +36,7 @@ uint SymbolCompletion::s_nACMaxEntries;
 
 /**
  * Class constructor.
+ * @param	pEditor	The editor object for which symbol completion is required
  * @param	pParent	Parent object
  * @param	szName	Optional object name
  */
@@ -234,10 +235,9 @@ void SymbolCompletion::slotAddEntry(FrontendToken* pToken)
 
 /**
  * Displays a code completion list, based on the results of the last query.
- * @param	pObj	An object that supports the CodeCompletionInterface of
- *					KTextEditor
+ * @param	nRecords	(ingnored)
  */
-void SymbolCompletion::slotQueryFinished(uint)
+void SymbolCompletion::slotQueryFinished(uint /* nRecords */)
 {
 	KTextEditor::CodeCompletionInterface* pCCI;
 	uint nEntryCount;
