@@ -155,6 +155,11 @@ uint SymbolDlg::getType() const
 	return m_pTypeCombo->currentItem();
 }
 
+bool SymbolDlg::getCase() const
+{
+	return !m_pCaseCheck->isChecked();
+}
+
 /**
  * A convinience static function for creating and showing SymbolDlg dialogue.
  * @param	pParent		The parent widget
@@ -165,7 +170,7 @@ uint SymbolDlg::getType() const
  *			string if the dialogue was cancelled
  */
 QString SymbolDlg::promptSymbol(QWidget* pParent, uint& nType, 
-	const QString& sSymbol)
+	const QString& sSymbol, bool& bCase)
 {
 	SymbolDlg dlg(pParent);
 	
@@ -180,6 +185,7 @@ QString SymbolDlg::promptSymbol(QWidget* pParent, uint& nType,
 	
 	// Return the text entered by the user
 	nType = dlg.getType();
+	bCase = dlg.getCase();
 	dlg.m_pSymbolHC->addToHistory(dlg.getSymbol());
 	s_slHistory = dlg.m_pSymbolHC->historyItems();
 	return dlg.getSymbol();
